Crate invoice

Crate invoice 

Structs

AmountParseError
Incorrect beneficiary format
BeneficiariesIter
BeneficiaryParseError
Incorrect beneficiary format
ConsignmentEndpointParseError
Incorrect consignment endpoint format
CurrencyData
Details
Invoice
NB: Invoice fields are non-public since each time we update them we must clear signature
Iso4217
LnAddress
LnPathHint
Path hints for a lightning network payment, equal to the value of the r key of the lightning BOLT-11 invoice https://github.com/lightningnetwork/lightning-rfc/blob/master/11-payment-encoding.md#tagged-fields
NotRgbInvoice
Error when an RGB-only operation is attempted on a non-RGB invoice.
Quantity

Enums

AmountExt
AssetClass
Beneficiary
ConsignmentEndpoint
An endpoint to a consignment exchange medium.
Iso4217Error
Recurrent