Invoice

Struct Invoice 

pub struct Invoice { /* private fields */ }
NB: Invoice fields are non-public since each time we update them we must clear signature

Implementations

Source

impl Invoice

pub fn version(&self) -> &u8

Method borrowing Invoice::version field. Version byte, always 0 for the initial version

pub fn amount(&self) -> &AmountExt

Method borrowing Invoice::amount field. Amount in the specified asset - a price per single item, if quantity

pub fn beneficiary(&self) -> &Beneficiary

Method borrowing Invoice::beneficiary field. Main beneficiary. Separating the first beneficiary into a standalone

pub fn alt_beneficiaries(&self) -> &Vec<Beneficiary>

Method borrowing Invoice::alt_beneficiaries field. List of beneficiary ordered in most desirable-first order, which follow

pub fn asset(&self) -> &Option<AssetId>

Method borrowing Invoice::asset field. AssetId can also be used to define blockchain. If it’s empty it implies

pub fn expiry(&self) -> &Option<NaiveDateTime>

Method borrowing Invoice::expiry field.

pub fn recurrent(&self) -> &Recurrent

Method borrowing Invoice::recurrent field. Interval between recurrent payments

pub fn quantity(&self) -> &Option<Quantity>

Method borrowing Invoice::quantity field.

pub fn currency_requirement(&self) -> &Option<CurrencyData>

Method borrowing Invoice::currency_requirement field. If the price of the asset provided by fiat provider URL goes below this

pub fn merchant(&self) -> &Option<String>

Method borrowing Invoice::merchant field.

pub fn purpose(&self) -> &Option<String>

Method borrowing Invoice::purpose field.

pub fn details(&self) -> &Option<Details>

Method borrowing Invoice::details field.

pub fn signature(&self) -> &Option<(PublicKey, Signature)>

Method borrowing Invoice::signature field.

pub fn consignment_endpoints(&self) -> &Vec<ConsignmentEndpoint>

Method borrowing Invoice::consignment_endpoints field. List of nodes which are able to accept RGB consignment

pub fn unknown(&self) -> &Stream

Method borrowing Invoice::unknown field.

Source

impl Invoice

pub fn new( beneficiary: Beneficiary, amount: Option<u64>, asset: Option<AssetId>, ) -> Invoice

pub fn with_descriptor( descr: Descriptor<DescriptorPublicKey>, amount: Option<u64>, chain: &Chain, ) -> Invoice

pub fn with_address(address: Address, amount: Option<u64>) -> Invoice

pub fn classify_asset(&self, chain: Option<Chain>) -> AssetClass

pub fn beneficiaries(&self) -> BeneficiariesIter<'_>

pub fn set_amount(&mut self, amount: AmountExt) -> bool

pub fn set_recurrent(&mut self, recurrent: Recurrent) -> bool

pub fn set_expiry(&mut self, expiry: NaiveDateTime) -> bool

pub fn set_no_expiry(&mut self) -> bool

pub fn set_quantity(&mut self, quantity: Quantity) -> bool

pub fn remove_quantity(&mut self) -> bool

pub fn set_currency_requirement(&mut self, currency_data: CurrencyData) -> bool

pub fn remove_currency_requirement(&mut self) -> bool

pub fn set_merchant(&mut self, merchant: String) -> bool

pub fn remove_merchant(&mut self) -> bool

pub fn set_purpose(&mut self, purpose: String) -> bool

pub fn remove_purpose(&mut self) -> bool

pub fn set_details(&mut self, details: Details) -> bool

pub fn remove_details(&mut self) -> bool

pub fn signature_hash(&self) -> MerkleNode

pub fn set_signature(&mut self, pubkey: PublicKey, signature: Signature)

pub fn remove_signature(&mut self)