Structs
- Amount
Parse Error - Incorrect beneficiary format
- Beneficiaries
Iter - Beneficiary
Parse Error - Incorrect beneficiary format
- Consignment
Endpoint Parse Error - Incorrect consignment endpoint format
- Currency
Data - Details
- Invoice
- NB: Invoice fields are non-public since each time we update them we must clear signature
- Iso4217
- LnAddress
- LnPath
Hint - Path hints for a lightning network payment, equal to the value of the
rkey of the lightning BOLT-11 invoice https://github.com/lightningnetwork/lightning-rfc/blob/master/11-payment-encoding.md#tagged-fields - NotRgb
Invoice - Error when an RGB-only operation is attempted on a non-RGB invoice.
- Quantity
Enums
- Amount
Ext - Asset
Class - Beneficiary
- Consignment
Endpoint - An endpoint to a consignment exchange medium.
- Iso4217
Error - Recurrent